@@ -24,7 +24,6 @@ from sys import version as pythvers
 import distro
 import psutil
 from cpuinfo import CPUINFO_VERSION_STRING as cpuivers
-from cpuinfo import get_cpu_info
 from distro import __version__ as distvers
 from psutil import __version__ as psutvers
 from PyQt5.QtCore import qVersion as pyqtvers
@@ -54,25 +53,3 @@ def return_obserware_information():
         "distvers": distvers,
     }
     return retndata
-
-
-def return_cpu_specifications_information():
-    retndata = {
-        "name": get_cpu_info().get("brand_raw"),
-        "vendor": get_cpu_info().get("vendor_id_raw"),
-        "frequency": get_cpu_info().get("hz_advertised_friendly"),
-        "count": get_cpu_info().get("count"),
-        "bits": get_cpu_info().get("bits"),
-        "arch": get_cpu_info().get("arch"),
-        "stepping": get_cpu_info().get("stepping"),
-        "model": get_cpu_info().get("model"),
-        "family": get_cpu_info().get("family"),
-    }
-    return retndata
-
-
-def return_feature_flags_information():
-    retndata = {"featflag": []}
-    if get_cpu_info().get("flags"):
-        retndata["featflag"] = get_cpu_info().get("flags")
-    return retndata
