@@ -30,52 +30,54 @@ logging.basicConfig(
 
 def log_process_interaction(logecode, prociden, taskverb):
     if logecode == 0:
-        logging.warning("PID %d was %s successfully" % (prociden, taskverb))
+        logetext = "PID %d was %s successfully" % (prociden, taskverb)
     elif logecode == 1:
-        logging.warning("PID %d could not be %s as it does not exist" % (prociden, taskverb))
-    elif logecode == 2:
-        logging.warning("PID %d could not be %s due to improper privileges" % (prociden, taskverb))
+        logetext = "PID %d could not be %s as it does not exist" % (prociden, taskverb)
+    else:
+        logetext = "PID %d could not be %s due to improper privileges" % (prociden, taskverb)
+    logging.warning(logetext)
+    return logetext
 
 
 def kill_process(prociden):
     taskverb = "killed"
     try:
         psutil.Process(prociden).kill()
-        log_process_interaction(0, prociden, taskverb)
+        return log_process_interaction(0, prociden, taskverb)
     except psutil.NoSuchProcess:
-        log_process_interaction(1, prociden, taskverb)
+        return log_process_interaction(1, prociden, taskverb)
     except psutil.AccessDenied:
-        log_process_interaction(2, prociden, taskverb)
+        return log_process_interaction(2, prociden, taskverb)
 
 
 def terminate_process(prociden):
     taskverb = "terminated"
     try:
         psutil.Process(prociden).terminate()
-        log_process_interaction(0, prociden, taskverb)
+        return log_process_interaction(0, prociden, taskverb)
     except psutil.NoSuchProcess:
-        log_process_interaction(1, prociden, taskverb)
+        return log_process_interaction(1, prociden, taskverb)
     except psutil.AccessDenied:
-        log_process_interaction(2, prociden, taskverb)
+        return log_process_interaction(2, prociden, taskverb)
 
 
 def resume_process(prociden):
     taskverb = "resumed"
     try:
         psutil.Process(prociden).resume()
-        log_process_interaction(0, prociden, taskverb)
+        return log_process_interaction(0, prociden, taskverb)
     except psutil.NoSuchProcess:
-        log_process_interaction(1, prociden, taskverb)
+        return log_process_interaction(1, prociden, taskverb)
     except psutil.AccessDenied:
-        log_process_interaction(2, prociden, taskverb)
+        return log_process_interaction(2, prociden, taskverb)
 
 
 def suspend_process(prociden):
     taskverb = "suspended"
     try:
         psutil.Process(prociden).suspend()
-        log_process_interaction(0, prociden, taskverb)
+        return log_process_interaction(0, prociden, taskverb)
     except psutil.NoSuchProcess:
-        log_process_interaction(1, prociden, taskverb)
+        return log_process_interaction(1, prociden, taskverb)
     except psutil.AccessDenied:
-        log_process_interaction(2, prociden, taskverb)
+        return log_process_interaction(2, prociden, taskverb)
