@@ -26,6 +26,7 @@ from obserware.sources.readers.mainwind import (
     tab_partitions,
     tab_performance,
     tab_processes,
+    tab_resources,
 )
 
 
@@ -38,8 +39,9 @@ class Worker(QObject):
         while True:
             time.sleep(1.5)
             statdict = {
-                "bottomstat": tab_performance.return_bottombar_threaded_statistics(),
+                "bottomstat": tab_resources.return_bottombar_threaded_statistics(),
                 "perfscreen": tab_performance.return_mainscreen_threaded_statistics(),
+                "rsrcscreen": tab_resources.return_mainscreen_threaded_statistics(),
                 "procscreen": tab_processes.return_processes_list(),
                 "ntwkscreen": {
                     "globrate": tab_network.return_global_network_rate(),
