@@ -17,6 +17,9 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
 
+import time
+from datetime import datetime
+
 from PyQt5.QtWidgets import QDialog
 
 from obserware import __version__
@@ -31,34 +34,56 @@ from obserware.sources.screens.procwind.interface import Ui_procwind
 
 
 class ProcWind(QDialog, Ui_procwind):
-    def __init__(self, prociden, parent=None):
+    def __init__(self, prociden, sttusbar, parent=None):
         super(ProcWind, self).__init__(parent)
         self.title = "PID #%s - Obserware v%s" % (prociden, __version__)
         self.prociden = int(prociden)
+        self.sttusbar = sttusbar
         self.setupUi(self)
         self.setWindowTitle(self.title)
-        self.handle_elements()
-
-    def handle_elements(self):
-        self.prepare_mainscreen_contents()
+        self.initialize_mainscreen_contents()
 
     def perform_process_killing(self):
-        kill_process(self.prociden)
+        self.sttusbar.showMessage(
+            "[%s] %s"
+            % (
+                datetime.fromtimestamp(time.time()).strftime("%H:%M:%S"),
+                kill_process(self.prociden),
+            )
+        )
         self.hide()
 
     def perform_process_termination(self):
-        terminate_process(self.prociden)
+        self.sttusbar.showMessage(
+            "[%s] %s"
+            % (
+                datetime.fromtimestamp(time.time()).strftime("%H:%M:%S"),
+                terminate_process(self.prociden),
+            )
+        )
         self.hide()
 
     def perform_process_resuming(self):
-        resume_process(self.prociden)
+        self.sttusbar.showMessage(
+            "[%s] %s"
+            % (
+                datetime.fromtimestamp(time.time()).strftime("%H:%M:%S"),
+                resume_process(self.prociden),
+            )
+        )
         self.hide()
 
     def perform_process_suspension(self):
-        suspend_process(self.prociden)
+        self.sttusbar.showMessage(
+            "[%s] %s"
+            % (
+                datetime.fromtimestamp(time.time()).strftime("%H:%M:%S"),
+                suspend_process(self.prociden),
+            )
+        )
         self.hide()
 
-    def prepare_mainscreen_contents(self):
+    def initialize_mainscreen_contents(self):
         retndata = return_mainscreen_onetimed_statistics(self.prociden)
         self.procname.setText(retndata["procname"])
         self.pcidtext.setText("#%d" % retndata["prociden"])
